#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

%if 0%{?fedora}
%global		with_python3 1
%global		__python_bin %{__python3}
%global		__python_sitelib %{python3_sitelib}
%else
%global		__python_bin %{__python2}
%global		__python_sitelib %{python2_sitelib}
%endif

%global		package_version 0.2.15
%global		package_name rhv-log-collector-analyzer

Name:           %{package_name}
Version:        0.2.16
Release:        0%{?release_suffix}%{?dist}
Summary:	RHV Log Collector - Analysis tools
BuildArch:      noarch

URL:            http://www.ovirt.org
Source0:        http://resources.ovirt.org/pub/src/%{package_name}/%{package_name}-%{package_version}.tar.gz
Patch0:         0001-rhv-image-discrepancies-use-correct-syntax-on-dump-c.patch
Patch1:         0002-rhv-image-discrepancies-compare-images-on-all-data-c.patch
Patch2:         0003-fix-storage-domain-filtering-in-rhv-image-discrepanc.patch


# In the past, users had an opition to install ovirt-log-collector-analyzer which
# currently should be replaced by rhv-log-collector-analyzer
Obsoletes:      ovirt-log-collector-analyzer

%if 0%{?with_python3}
Requires:       python3
BuildRequires:  python3-devel
%else
Requires:       python
BuildRequires:  python2-devel
%endif

Requires:	gnutls-utils
Requires:	rubygem-asciidoctor
Requires:	libxml2
Requires:	openssl
Requires:	engine-db-query >= 1.2.0

Requires:	insights-client

BuildRequires:  git

%if 0%{?rhel} >= 7 || 0%{?fedora}
Requires:       ovirt-engine
%else
Requires:       rhevm-setup
%endif

Requires:	coreutils
Requires:	util-linux
License:	ASL 2.0 and GPLv2+

%description
This package contains tools to help analyze oVirt Log Collector archives

%prep
%setup -q -n %{package_name}-%{package_version}
%patch0 -p1
%patch1 -p1
%patch2 -p1


%build
%configure \
	--docdir="%{_docdir}/%{package_name}-%{version}" \
	--disable-python-syntax-check \
	PYTHON="%{__python_bin}"
make %{?_smp_mflags}

%check
make check

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"

%files
%doc AUTHORS
%license COPYING
%license COPYING-GPL
%{_bindir}/rhv-log-collector-analyzer
%{_bindir}/rhv-image-discrepancies
%{_bindir}/rhv-log-collector-analyzer-live
%{_bindir}/rhv-analyzer-insights
%{_sysconfdir}/cron.daily/rhv-analyzer-insights
%config(noreplace) %{_sysconfdir}/ovirt-engine/rhv-log-collector-analyzer/rhv-log-collector-analyzer.conf
%dir %{_datadir}/%{name}/analyzer
%{_datadir}/%{name}/analyzer/
%{_mandir}/man8/rhv-log-collector-analyzer.8*
%{_mandir}/man8/rhv-analyzer-insights.8*
%{__python_sitelib}/rhv_log_collector_analyzer/*
%dir %{__python_sitelib}/rhv_log_collector_analyzer

%changelog
* Wed Mar 19 2020 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.16-0
- rhv-image-discrepancies: use correct syntax on dump
- rhv-image-discrepancies: compare images on all data-centers
- fix storage domain filtering in rhv-image-discrepancies


* Mon Dec 09 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.15-0
- rhv-image-discrepancies: Use python2 in shebang

* Mon Nov 11 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.14-0
- db-storage discrepancies checker
- rhv-image-discrepancies: Add into the Makefile build

* Tue Nov 05 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.13-0
- analyzer: Add back --html
- Fixed the comment to properly indicate the task according to the sql query which is being executed.
- Added the KCS link for the deprecated CPU in the cluster.py file

* Thu Oct 17 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.12-0
- misc: fix my_func_name function
- man: add --version info
- analyzer: fix --version

* Wed Sep 18 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.11-0
- analyzer: Show all network(s) available
- analyzer: Replace disabled-warning-check with whitelist
- sql: Add "Virtual Machine" for AS statement
- power_management: fix msg to users

* Sun Aug 18 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.10-0
- build: Fix rpm build for Fedora 29 or higher
- man: Add manpage to rhv-analyzer-insights
- man: remove legacy manpage from ovirt-log-collector

* Fri Aug 09 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.9-0
- sh: remove tar-file message from help
- sh: remove deprecated msg about .tar file

* Wed Jul 31 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.8-0
- analyzer: remove depreacted options

* Mon Jul 29 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.7-0
- sh: require users to run the script as root

* Tue Jul 23 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.6-0
- sql: improve check_deprectated_api
- analyzer: rename dup function check_api_basic_auth_thrash
- engine: improve desc_success messsage to users
- sql: fix GROUP BY in vms_from_pool_with_init.sql
- vms: Add desc_success var into vms pools validation
- live: fix typo in func name

* Tue Jul 23 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.5-0
- rhv-analyzer-insights: avoid info msg in case insights not enabled
- check for deprecated API uses
- sp: update table field
- Makefile: Fix typo
- check for basic auth call flood
- unpackAndPrepareDump.sh: Support multiple versions of postgresql
- check for pools containing vms with edited sysprep
- add warning for missing ca.pem
- wsgi: sycn with last changes
- rhv-log-collector-analyzer: rename check_tls_disabled
- conf: Add hosts in comment rhv-log-collector-analyzer.conf
- conf: rhv-log-collector-analyzer
- rhv-log-collector-analyzer: renamed functions in engine.py
- rhvanalyzer: rename non default value in vdc_options
- rhv-log-collector-analyzer: rename function check_mixed_rhel_versions
- rename: check_deprecated_CPUs_in_cluster_4_3_or_higher
- cluster: rename check_no_datacenter_assigned
- cluster: rename check_legacy_policy
- cluster: rename policy_custom_properties_empty function
- rhv-log-collector-analyzer: Add filter option for insights
- spec: use %config(noreplace) to insights conf
- aaa: rename function to avoid dup name
- rhv-log-collector-analyzer: rename func in hosts and vms
- rhv-log-collector-analyzer: rename functions to avoid dup names
- wsgi: update wsgi with upstream
- --live: Check if slaves are in the same aggregation groups as bond

* Mon Mar 25 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.4-0
- spec: Add insights-client
- App to consume Insights Message Queue
- insights: do not tar parent dir only json
- --live: json cleanup
- --live: split config reader into specific py
- rhv-analyzer-insights
- --live: VM(s) with unmanaged disks/interfaces
- --live: Check Virtual Machines with unmanaged devices
- --live: check for bonds with incorrect configuration
- revert: sql: Readded AMD Opteron G3 CPU
- sql: use proper table for windows timezone
- sql: Readded AMD Opteron G3 CPU
- sql: fix vms_query_pinned_vms_to_unknown_hypervisor

* Wed Jan 16 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.3-0
- --live: Check if Engine CA has 1 year left

* Mon Jan 14 2019 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.2-0
- --live: Add ca.pem data

* Tue Sep 11 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.1-0
- --live: Add certtool validation for CA

* Tue Sep 11 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.2.0-0
- - gitignore: add src/inventory-profile
- analyzer: handle postgresql10
- analyzer: warn if cluster/datacenter are < 4.1
- analyzer: check if vdc_options contain non default values
- --live: display rpms installed in the Engine
- --live: optimization for INFO
- analyzer: improve outdated config message
- --live: optimization for a if block
- --live: Use Font Awesome for WARNING messages

* Tue Sep 11 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.1.7-0
- rhbz#1620271 - enable rhv_analyzer plugin for sos >= 3.6

* Tue Sep 11 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.1.6-0
- rhbz#1618739 - sql: handle multiple unknown hypervisors

* Wed Aug 15 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.1.5-0
- spec: require engine-db-query >= 1.2.0

* Wed Aug 15 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.1.4-0
- analyzer does not clean its temp files after failure - rhbz#1539029

* Tue Aug 14 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.1.3-0
- rhv-log-collector-analyzer should obsolete/provide ovirt-log-collector-analyzer - rhbz#1608328
- analyzer does not clean its temp files after failure - rhbz#1539029

* Fri Jul 20 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 0.1.2-0
- release 0.1.2-0

* Wed Apr 25 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.3.0
- initial release
